@@ -14,5 +14,5 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with pytsm.  If not, see <http://www.gnu.org/licenses/>.
-from .core import dsmadmc  # NOQA
+from .core import dsmadmc, Failed  # NOQA
 from .formatter import get_formatter  # NOQA
